@@ -15,7 +15,7 @@ def get_type_object(data_type):
         "varchar": str,
         "text": str,
         "nvarchar": str,
-        "smallint": str,
+        "smallint": int,
         "char": str,
 
         "int": int,
@@ -38,6 +38,5 @@ def get_type_object(data_type):
 
         "boolean": bool,
         "bool": bool,
-        None: None
 
     }.get(data_type.lower())
