@@ -1,15 +1,17 @@
 from datetime import datetime, date
 from enum import Enum
 import json
-from uuid import uuid4
+from uuid import uuid4, UUID
 
 def get_type_object(data_type):
     """
     :param data_type: data type
     :return: object class
     """
+    
     return {
-        "uuid": uuid4,
+        "uuid": UUID,
+        "string": str,
         "str": str,
         "varchar": str,
         "text": str,
@@ -36,6 +38,5 @@ def get_type_object(data_type):
 
         "boolean": bool,
         "bool": bool,
-        None: None
 
     }.get(data_type.lower())
